@@ -7,9 +7,10 @@ DEFAULT = 'off'
 CHECK_NAME = 'isort'
 NO_ISORT_MSG = ("isort is required for the flake8 plugin.\n"
                 "`pip install isort` or turn it off in your tox.ini file.")
+REQUIRED_FILES = ['.editorconfig', '.isort.cfg', 'setup.cfg']
 
 
-def run(files):
+def run(files, temp_folder):
     "Check flake8 errors in the code base."
     try:
         import isort  # NOQA
