@@ -96,14 +96,19 @@ def main(commit_only=True):
         for name, mod in checks():
             default = getattr(mod, 'DEFAULT', 'off')
             if hook_checks.is_enabled(name, default=default):
+                if hasattr(mod, 'REQUIRED_FILES'):
+                    for filename in mod.REQUIRED_FILES:
+                        if os.path.isfile(filename):
+                            shutil.copy(filename, TEMP_FOLDER)
                 args = hook_checks.arguments(name)
                 if args:
-                    errors = mod.run(files, args)
+                    errors = mod.run(files, TEMP_FOLDER, args)
                 else:
-                    errors = mod.run(files)
+                    errors = mod.run(files, TEMP_FOLDER)
                 if errors:
                     title_print("Checking {0}".format(name))
                     print((errors.replace(TEMP_FOLDER + "/", '')))
+                    print("")
                     exit_code = 1
 
     if exit_code == 1:
